@@ -914,8 +914,11 @@ void ExtenderPrivate::adjustSize()
 {
     QRect screenRect;
     QSizeF size = mainWidget->effectiveSizeHint(Qt::PreferredSize);
-    if (applet && applet.data()->containment() && applet.data()->containment()->corona()) {
-        screenRect = applet.data()->containment()->corona()->screenGeometry(applet.data()->containment()->screen());
+    if (applet) {
+        Containment *containment = applet.data()->containment();
+        if (containment && containment->corona()) {
+            screenRect = containment->corona()->screenGeometry(containment->screen());
+        }
     }
     q->resize(qMin(screenRect.width()/3, (int)size.width()),
               qMin(screenRect.height()/3, (int)size.height()));
